[Roxygen-commits] r127 - in pkg: R sandbox
noreply at r-forge.r-project.org
noreply at r-forge.r-project.org
Tue Jul 29 05:50:10 CEST 2008
Author: pcd
Date: 2008-07-29 05:50:10 +0200 (Tue, 29 Jul 2008)
New Revision: 127
Modified:
pkg/R/parse.R
pkg/sandbox/callgraph.R
Log:
callgraph keywords; we should really do this in the roclets
Modified: pkg/R/parse.R
===================================================================
--- pkg/sandbox/callgraph.R 2008-07-29 03:49:55 UTC (rev 126)
+++ pkg/sandbox/callgraph.R 2008-07-29 03:50:10 UTC (rev 127)
@@ -54,7 +54,7 @@
discover.subcalls <- function(exprofundum,
depth=2,
- include.primitives=TRUE)
+ include.primitives=FALSE)
if (is.name(exprofundum)) {
subcall <- as.character(exprofundum)
if (is.callable(subcall, include.primitives) &&
More information about the Roxygen-commits
mailing list
--- pkg/R/parse.R 2008-07-29 03:49:55 UTC (rev 126)
+++ pkg/R/parse.R 2008-07-29 03:50:10 UTC (rev 127)
@@ -170,9 +170,9 @@
#' Parsers with a mandatory value.
#' @name value.parsers
#' @aliases prototype exportClass exportMethod exportPattern S3method
#' @aliases import importFrom importClassesFrom importMethodsFrom name
#' @aliases aliases title usage references concept note seealso example
#' @aliases examples keywords return author include
register.preref.parsers(parse.value,
'prototype',
'exportClass',
@@ -196,7 +196,8 @@
'keywords',
'return',
'author',
- 'include')
+ 'include',
+ 'callGraphDepth')
#' Parse an element containing a mandatory name
#' and description (such as @@param).
@@ -254,10 +255,13 @@
#' Toggling parsers
#' @name toggle.parsers
#' @aliases listObject attributeObject environmentObject
+#' callGraph callGraphPrimitives
register.preref.parsers(parse.toggle,
'listObject',
'attributeObject',
- 'environmentObject')
+ 'environmentObject',
+ 'callGraph',
+ 'callGraphPrimitives')
#' By default, srcrefs are ignored; this parser returns \code{nil}.
#' @param pivot the parsing pivot
Modified: pkg/sandbox/callgraph.R
@@ -170,9 +170,9 @@
#' @name value.parsers
#' @aliases prototype exportClass exportMethod exportPattern S3method
-#' @aliases import importFrom importClassesFrom importMethodsFrom name
-#' @aliases aliases title usage references concept note seealso example
-#' @aliases examples keywords return author include
+#' import importFrom importClassesFrom importMethodsFrom name
+#' title usage references concept note seealso example
+#' examples keywords return author include callGraphDepth
register.preref.parsers(parse.value,
'prototype',
===================================================================